#===============================================================================
#. Ttulo : Medidas Estatsticas - posio (ou separatrizes)
# Autores: Gabriel Figueiredo, Matheus Almeida e Ra Bizerra
# Objetivo: Clculo das principais medidas estatsticas no R
# Correes e adies: 2024-06-04 17:50:54 - J.C.Faria
#===============================================================================

#. Posio ou separatrizes
#  - Quartis
#  - Decis
#  - Percentis

#. Carregando os pacotes necessrios
# install.packages('fdth')
library(fdth)

#--------------------------------------------------
#. Funo           Medida             Pacote
#--------------------------------------------------
#  median           mediana            base, fdth
#  quantile         quantis            base, fdth
#--------------------------------------------------

#. Medidas de posio ou separatrizes
#.. Quartis
#... Vetor
(k <- c(1, 1, 2, 3, 5, 5, 6, 7, 9, 9, 10, 13))

# observar que o resultado so 5 valores: 0%   25%   50%   75%  100%
quantile(k)

# podar extremos: 3 quartis
quantile(k)[2:4]

# Observar:
(q3 <- quantile(k)[4])
(q1 <- quantile(k)[2])

# Amplitude inter-quartlica
(aiq <- as.numeric(q3 - q1))

#... A partir de uma fdt
(tb <- make.fdt(f=c(4, 9, 11, 8, 5, 3),
                start=50,
                end=74))

methods(quantile)
str(quantile.fdt)

# quantile.fdt
quantile(tb)

#... Todos os quartis
vq <- numeric()
for(n in 1:3)
  vq[n] <- quantile(tb,
                    i=n,
                    probs=seq(0, 1, .25))

names(vq) <- paste0(c(25, 50, 75),
                    '%')
round(vq, 2)


#.. Decis
#... Vetor
(k <- c( 1,  3, 5,  6,  6,  9,  10, 13, 15, 20,
        22, 24, 25, 29, 31, 31, 39, 40, 55, 90, 91))

quantile(k,
         p=seq(0, 1, .1))[2:10]   # todos os decis

#... A partir de uma fdt
(tb <- make.fdt(f=c(4, 9, 11, 8, 5, 3),
                start=50,
                end=74))

methods(quantile)
str(quantile.fdt)
d3 <- quantile(tb,
               i=3,  # decil 3
               probs=seq(0, 1, .1))      # quantile.fdt
round(d3, 2)

#... Todos os decis
vd <- numeric()
for(n in 1:9)
  vd[n] <- quantile(tb,
                    i=n,
                    probs=seq(0, 1, .1))

names(vd) <- paste0(1:9,
                    '%')
round(vd, 2)


#.. Percentis
#... Vetor
k <- c(31, 31, 37, 40, 48, 50, 51, 51, 60, 62,
       64, 65, 65, 65, 66, 74, 74, 88, 91, 92)

quantile(k,
         p=seq(0, 1, .01))[2:100]  # todos os percentis

quantile(k,
         p=seq(0, 1, .01))[71]     # percentil 70

#... A partir de uma fdt
(tb <- make.fdt(f=c(5, 7, 4, 2, 2),
                start=4,
                end=24))

methods(quantile)
str(quantile.fdt)
quantile(tb,
         i=75,  # percentil 75
         probs=seq(0, 1, .01))  # quantile.fdt

#... Todos os percentis
vp <- numeric()
for(n in 1:99)
  vp[n] <- quantile(tb,
                    i=n,
                    probs=seq(0, 1, .01))

names(vp) <- paste0(1:99,
                    '%')
round(vp, 2)
